@@ -1,7 +1,5 @@
 from django.http import JsonResponse, HttpResponse
 from django.shortcuts import render
-from django.utils.decorators import method_decorator
-from django.views.decorators.csrf import csrf_exempt
 from furl import furl
 from django.views.generic import View
 from json import loads as unjsonize
