@@ -1,7 +1,10 @@
 from oauth2_provider.views.mixins import ProtectedResourceMixin, OAuthLibMixin
-from .base import method_decorator, csrf_exempt, view_catch_error, BaseCrudView, BaseView
+from .base import view_catch_error, BaseCrudView, BaseView
 from .lookups import ChoicesView
 
+from django.utils.decorators import method_decorator
+from django.views.decorators.csrf import csrf_exempt
+
 
 # def set_user(f): TODO
 #     def wrap(self, request, *args, **kwargs):
